@@ -26,7 +26,7 @@ def delete_dbl_spaces(value):
 
     if not isinstance(value, str):
         return ToStr(value)
-    return re.sub('\s+', ' ', value).strip();
+    return re.sub('\s+', ' ', value).strip()
 
 
 def null2blanck(str):
